A CLI tool to build and deploy projects with Sleakops

SleakOps relies on the best practices to automate all the repetitive tasks of your scalable applications. Run your apps on the Cloud without worrying about your DevOps support.
